#
# spec file for package perl-Test-Class
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Class
Name:           perl-Test-Class
Version:        0.52
Release:        1.17
Summary:        Easily create test classes in an xUnit/JUnit style
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SZ/SZABGAB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(MRO::Compat) >= 0.11
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Test::Builder) >= 0.78
BuildRequires:  perl(Test::Exception) >= 0.250000
BuildRequires:  perl(Test::More) >= 0.78
BuildRequires:  perl(Test::Simple) >= 0.78
BuildRequires:  perl(Try::Tiny)
Requires:       perl(MRO::Compat) >= 0.11
Requires:       perl(Module::Runtime)
Requires:       perl(Test::Builder) >= 0.78
Requires:       perl(Test::Simple) >= 0.78
Requires:       perl(Try::Tiny)
%{perl_requires}

%description
Test::Class provides a simple way of creating classes and objects to test
your code in an xUnit style.

Built using Test::Builder, it was designed to work with other Test::Builder
based modules (Test::More, Test::Differences, Test::Exception, etc.).

_Note:_ This module will make more sense, if you are already familiar with
the "standard" mechanisms for testing perl code. Those unfamiliar with
Test::Harness, Test::Simple, Test::More and friends should go take a look
at them now. Test::Tutorial is a good starting point.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Thu Feb 18 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.52
  see /usr/share/doc/packages/perl-Test-Class/Changes
  0.52   [2021-02-17]
  - Change bugtracker link to point GitHub issues instead of RT.
  - Remove some old and broken links.
  - Work by (Kaycie Goodman).
  - Test fix (Pali, PR#32).
  - Fix reporting caller information (file+line) when number of tests does
    not match (Pali).
  - Use better class names in t/runtests_return.t (Pali).
  - Fix documentation to be more accurate regarding support and author
    activity (Karen Etheridge).
  - Ensure metadata is processed as v2 (Karen Etheridge).
  - Remove unnecessary shebangs (Karen Etheridge).
  - chmod ugo-x (Karen Etheridge).
  0.51   [2019-04-29]
  - Create fail_if_returned_late (Jason Terry, Oaxlin, PR#23)
* Sun Jun  7 2015 coolo@suse.com
- updated to 0.50
  see /usr/share/doc/packages/perl-Test-Class/Changes
  0.50   [2015-06-07]
  - add links to Ovid's tutorial series on Test::Class (Tim Vroom, PR#19)
  - add links to Test::Class::Most, Test::Class::Moose (Tim Vroom, PR#20)
  - list some distributions that use Test::Class in their test suite (Tim
    Vroom, PR#21)
  - update documentation about running individual tests (Matthew Horsfall,
    PR#22)
  - fix some tests to work with the new Test::Stream (Chad Granum, PR#27)
  - switch packaging to ExtUtils::MakeMaker
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.48
  see /usr/share/doc/packages/perl-Test-Class/Changes
  0.48   [2014-11-06]
  - replace a few bare evals with more modern alternatives
  0.47   [2014-09-26]
  - fixes for Test::More 1.301001_* series (PR#17, PR#18, Chad Granum)
* Mon Sep 15 2014 coolo@suse.com
- updated to 0.46
  - fix new teardown tests for MSWin32
  0.45   [2014-07-05]
  - bump minimum required version of Test::More (RT#96951)
  0.44   [2014-07-04]
  - run teardown method even if test method dies, as in version 0.37 and
    earlier
  0.43   [2014-06-25]
  - specify test prereqs as test_requires rather than build_requires
  0.42   or the "how did I get stuck with co-maint?" release [2014-05-07]
  - properly handle thrown exceptions that stringify to the empty string
    before or after chomping (Karen Etheridge, PR#11)
* Mon Dec  9 2013 coolo@suse.com
- updated to 0.41
  - require a newer Test::Builder if 0.99 is installed RT#90699
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.40
  - Applied Zefram's fix for RT#89473, Test::Class fails on Test::Builder
    0.99
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.39
  - Merged schwern's https://github.com/adrianh/test-class/pull/2
    "Fix Test::Class for Test::Builder 1.5" - thank you Schwern!
  - Many thanks to the ever excellent Ovid for actually making this happen.
  - die-in-setup.t will work on Windows (thanks to Alexandr Ciornii for
    the patch)
  - Fix docs to explain "no_plan" in start up" (thanks to skington for the
    patch)
  - Fixed RT#64470: minor documentation error in Test::Class::Load (thanks
    to Andrew Grangaard for patch)
  - Fixed RT#39266: Test::Class with Package::Alias
  - Fixed RT#56636: feature request: option to turn off auto-skipping
    uncompleted tests (thanks to Ken Fox for suggestion) with addition
    of fail_if_returned_early() (thanks to Dave Evans for patch)
  - Fixed RT#64268: dying in setup does not skip rest of test
  - Startup and shutdown methods are no longer run if a class will not
    run any test methods
  - Updated acknowledgements
  - Added missing filter tests to MANIFEST & distribution
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov 19 2010 pascal.bleser@opensuse.org
- initial package (0.36)
